# mypy-boto3-glacier

[![PyPI - mypy-boto3-glacier](https://img.shields.io/pypi/v/mypy-boto3-glacier.svg?color=blue)](https://pypi.org/project/mypy-boto3-glacier)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-glacier.svg?color=blue)](https://pypi.org/project/mypy-boto3-glacier)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.Glacier 1.14.19](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/glacier.html#Glacier) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.2.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

## How to install

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `Glacier` service.

```bash
python -m pip install boto3-stubs[glacier]
```

## How to use

### Client annotations

`GlacierClient` provides annotations for `boto3.client("glacier")`.

```python
import boto3

from mypy_boto3_glacier import GlacierClient, GlacierServiceResource
from mypy_boto3_glacier.paginator import (
    ListJobsPaginator,
    ListMultipartUploadsPaginator,
    ListPartsPaginator,
    ListVaultsPaginator,
)
from mypy_boto3_glacier.service_resource import (
    Account,
    Archive,
    Job,
    MultipartUpload,
    Notification,
    ServiceResourceVaultsCollection,
    Vault,
)
from mypy_boto3_glacier.type_defs import CSVInputTypeDef, ...
from mypy_boto3_glacier.waiter import VaultExistsWaiter, VaultNotExistsWaiter

client: GlacierClient = boto3.client("glacier")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: GlacierClient = session.client("glacier")
```

### Paginators annotations

`mypy_boto3_glacier.paginator` module contains type annotations for all paginators.

```python

client: GlacierClient = boto3.client("glacier")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
list_multipart_uploads_paginator: ListMultipartUploadsPaginator = client.get_paginator("list_multipart_uploads")
list_parts_paginator: ListPartsPaginator = client.get_paginator("list_parts")
list_vaults_paginator: ListVaultsPaginator = client.get_paginator("list_vaults")
```


### Waiters annotations

`mypy_boto3_glacier.waiter` module contains type annotations for all waiters.

```python

client: GlacierClient = boto3.client("glacier")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
vault_exists_waiter: VaultExistsWaiter = client.get_waiter("vault_exists")
vault_not_exists_waiter: VaultNotExistsWaiter = client.get_waiter("vault_not_exists")
```


### Service Resource annotations

`GlacierServiceResource` provides annotations for `boto3.resource("glacier")`.

```python

resource: GlacierServiceResource = boto3.resource("glacier")

# now resource usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_resource: GlacierServiceResource = session.resource("glacier")
```


### Other resources annotations

`mypy_boto3_glacier.service_resource` module contains type annotations for all resources.

```python

resource: GlacierServiceResource = boto3.resource("glacier")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
my_account: Account = resource.Account(...)
my_archive: Archive = resource.Archive(...)
my_job: Job = resource.Job(...)
my_multipart_upload: MultipartUpload = resource.MultipartUpload(...)
my_notification: Notification = resource.Notification(...)
my_vault: Vault = resource.Vault(...)
```



### Collections annotations

`mypy_boto3_glacier.service_resource` module contains type annotations
for all `GlacierServiceResource` collections.

```python

resource: GlacierServiceResource = boto3.resource("glacier")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
vaults: glacier_resources.ServiceResourceVaultsCollection = resource.vaults
```




### Typed dictionations

`mypy_boto3_glacier.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python

def get_structure() -> CSVInputTypeDef:
    return {
      ...
    }
```


## Dynamic type annotations

`mypy_boto3` command generates `boto3.client/resource` type annotations for
`mypy_boto3_glacier` and other installed services.

```bash
# Run this command after you add or remove service packages
python -m mypy_boto3
```

Generated type annotations provide overloads for `boto3.client` and `boto3.resource`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully if you have many services installed
- `VSCode` does not currently support function overloads, use explicit type annotations

```python

# Type is discovered correctly by mypy and PyCharm
# VSCode still needs explicit type annotations
client = boto3.client("glacier")
resource = boto3.resource("glacier")

session_client = boto3.Session().client("glacier")
session_resource = boto3.Session().resource("glacier")
```
